@@ -1,48 +1,28 @@
-# ATtila
-# Developed by Christian Visintin
-#
-# MIT License
-# Copyright (c) 2019 Christian Visintin
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-
-from .exceptions import ATSerialPortError
 from .atcommand import ATCommand
 from .atresponse import ATResponse
 
 import re
-from typing import List, Optional, Union, Tuple
+from typing import List, Dict, Optional, Union, Tuple
+
 
 class ATSession(object):
     """
     This class represents an AT sessions, which is a set of commands to execute - "a script".
     It takes care of preparing the next command to execute based on the response of the previous one
-    and of validating the response of the last command. 
+    and of validating the response of the last command.
     """
 
-    def __init__(self, commands: List[str] = []):
+    def __init__(self, commands: Optional[List[ATCommand]]):
         """
         Class constructor. Instantiates a new :class:`.ATSession.` object with the provided parameters.
 
         :param commands: list of ATCommand which will become the set of instructions for this session.
         :type commands: list
         """
-        self._commands = commands
-        self._session_storage = {}
+        if commands is None:
+            commands = []
+        self._commands: List[ATCommand] = commands
+        self._session_storage: Dict[str, Union[str, int]] = {}
         self._current_command_index = 0
         self._last_command_failed = False
 
@@ -83,7 +63,15 @@ class ATSession(object):
         self._commands.append(command)
         return True
 
-    def add_new_command(self, command: str, exp_response: str, tout:int = None, delay: int = 0, collectables: Optional[List[str]] = None, dganger: Optional[ATCommand] = None) -> bool:
+    def add_new_command(
+        self,
+        command: str,
+        exp_response: str,
+        tout: int = None,
+        delay: int = 0,
+        collectables: Optional[List[str]] = None,
+        dganger: Optional[ATCommand] = None,
+    ) -> bool:
         """
         Add a new command at the end of the command list
 
@@ -104,8 +92,9 @@ class ATSession(object):
         """
         if not command:
             return False
-        new_command = ATCommand(command, exp_response,
-                                tout, delay, collectables, dganger)
+        new_command = ATCommand(
+            command, exp_response, tout, delay, collectables, dganger
+        )
         self._commands.append(new_command)
         return True
 
@@ -184,24 +173,23 @@ class ATSession(object):
             if not response_str:
                 self._last_command_failed = True
         # Instance ATResponse
-        atresponse = ATResponse(response_str, response,
-                                current_command, execution_time)
+        atresponse = ATResponse(response_str, response, current_command, execution_time)
         # If last command failed => set doppelganger as next command
         if self._last_command_failed:
             # @! Response NOK
             doppelganger = current_command.doppel_ganger
             if doppelganger:
                 # Add command to command list
-                self._commands.insert(
-                    self._current_command_index, doppelganger)
+                self._commands.insert(self._current_command_index, doppelganger)
         else:
             # @! Response OK
             # Try to get collectables
             if vars_to_collect:
                 for to_collect in vars_to_collect:  # String
                     collected = self.__get_value_from_response(
-                        to_collect, response)  # collected => tuple(key, value)
-                    if collected:
+                        to_collect, response
+                    )  # collected => tuple(key, value)
+                    if collected is not None:
                         self._session_storage[collected[0]] = collected[1]
                         atresponse.add_collectable(collected[0], collected[1])
         # Instance response object
@@ -216,14 +204,16 @@ class ATSession(object):
         :returns string
         """
         # Get session variable
-        while re.search("\\${(.*?)}", haystack):
+        while True:
             reg_result = re.search("\\${(.*?)}", haystack)
+            if reg_result is None:
+                break
             key_group = reg_result.group(0)
             key_name = key_group[2:-1]
             # @! Okay, there is a session variable to replace
             # Search for session variable
             session_value = self._session_storage.get(key_name)
-            if not session_value:
+            if session_value is None:
                 # If not found set to empty
                 session_value = ""
             # Replace session variable
@@ -255,7 +245,7 @@ class ATSession(object):
         :param key
         :param value
         :type key: String
-        :type value: Any
+        :type value: Union[str, int]
         """
         self._session_storage[key] = value
 
@@ -266,15 +256,17 @@ class ATSession(object):
 
         :param key
         :type key: String
-        :returns any
+        :returns Union[str, int]
         :raises KeyError
         """
-        if not self._session_storage.get(key):
-            raise KeyError(
-                "Could not find %s in current session storage" % key)
-        return self._session_storage.get(key)
+        try:
+            return self._session_storage[key]
+        except KeyError:
+            raise KeyError("Could not find %s in current session storage" % key)
 
-    def __get_value_from_response(self, to_collect: str, response: List[str]) -> Optional[Tuple[str, Union[str, int]]]:
+    def __get_value_from_response(
+        self, to_collect: str, response: List[str]
+    ) -> Optional[Tuple[str, Union[str, int]]]:
         """
         Get a value from response.
         The collectable syntax is '...?{KEY_NAME}...'
@@ -298,7 +290,7 @@ class ATSession(object):
         if len(key_parts) > 1:
             key_regex = key_parts[1]
         key_name = key_parts[0]
-        #part_to_remove = to_collect.replace(key_group, "")
+        # part_to_remove = to_collect.replace(key_group, "")
         key_value = None
         # compose regex with to_collect[0] + (.*) + to_collect[1]
         regex = to_collect.replace(key_group, "")
@@ -308,13 +300,12 @@ class ATSession(object):
         else:
             collect_expr_parts = to_collect.split(key_group)
         # Collect regex part to build regex; excape parts
-        part_to_remove = []
+        part_to_remove: List[str] = []
         if len(collect_expr_parts) > 0:
             for i in range(len(collect_expr_parts)):
                 if not collect_expr_parts[i]:  # Skip empty tokens
                     continue
-                collect_expr_parts[i] = self.replace_session_keys(
-                    collect_expr_parts[i])
+                collect_expr_parts[i] = self.replace_session_keys(collect_expr_parts[i])
                 # First collect this part in parts to remove
                 part_to_remove.append(collect_expr_parts[i])
                 # Then escape regex
@@ -328,7 +319,8 @@ class ATSession(object):
             regex = "(.*)"
         # Iterate over lines
         for line in response:
-            if re.search(regex, line):
+            search = re.search(regex, line)
+            if search is not None:
                 # If a key regex is set, check if line complies
                 if key_regex:
                     key_regex_match = re.search(key_regex, line)
@@ -337,7 +329,7 @@ class ATSession(object):
                     else:
                         # Line doesn't comply
                         continue
-                key_value = re.search(regex, line).group()
+                key_value = search.group()
                 for part in part_to_remove:
                     key_value = key_value.replace(part, "")
                 try:
@@ -346,7 +338,7 @@ class ATSession(object):
                     break
                 break
         # Return values
-        if key_value:
+        if key_value is not None:
             return (key_name, key_value)
         else:
             return None
