@@ -1,31 +1,18 @@
-# ATtila
-# Developed by Christian Visintin
-#
-# MIT License
-# Copyright (c) 2019 Christian Visintin
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-
 from attila.virtual.exceptions import VirtualSerialException
 
 from typing import Callable, Optional
 
+
 class VirtualSerial(object):
-    def __init__(self, serial_port: str, baudrate: int, timeout: int = 0, read_callback: Optional[Callable[[], str]] = None, write_callback: Optional[Callable[[str], None]] = None, in_waiting_callback: Optional[Callable[[], int]] = None):
+    def __init__(
+        self,
+        serial_port: str,
+        baudrate: int,
+        timeout: int = 0,
+        read_callback: Optional[Callable[[], str]] = None,
+        write_callback: Optional[Callable[[str], None]] = None,
+        in_waiting_callback: Optional[Callable[[], int]] = None,
+    ):
         """
         Class constructor. Instantiates a new :class:`.virtual.VirtualSerial` object with the provided parameters.
 
@@ -89,8 +76,7 @@ class VirtualSerial(object):
         Open virtual serial
         """
         if not self.serial_port or not self.baudrate:
-            raise VirtualSerialException(
-                "Could not open %s" % self.serial_port)
+            raise VirtualSerialException("Could not open %s" % self.serial_port)
         return True
 
     def close(self):
@@ -98,8 +84,7 @@ class VirtualSerial(object):
         Open virtual serial
         """
         if not self.serial_port or not self.baudrate:
-            raise VirtualSerialException(
-                "Could not close %s" % self.serial_port)
+            raise VirtualSerialException("Could not close %s" % self.serial_port)
         return True
 
     def write(self, data: bytes) -> bool:
